### R code from vignette source 'MetShot.Rnw'

###################################################
### code chunk number 1: LibraryPreload
###################################################
library(xcms)
library(CAMERA)
library(MetShot)
library(faahKO)




###################################################
### code chunk number 2: open the file
###################################################

##
## finish the faahKO data
##

faahko <- group(faahko)
faahko <- fillPeaks(faahko)

##
## Create the annotation for putative [M+H]+
##
xa_pos <- xsAnnotate(faahko)
xa_pos <- groupFWHM(xa_pos)

xa_pos <- findIsotopes(xa_pos)
xa_pos <- groupCorr(xa_pos)
xa_pos <- findAdducts(xa_pos,
                      ppm=100, mzabs=0.1,
                      polarity="positive")

p <- getPeaklist(xa_pos)


## Find Interesting peaks
dr <- diffreport(faahko, sortpval=FALSE)

## Interesting groups have to be
## 1) potential [M+H]
## 2) differental
## 3) with a minimum intensity

targetgroups <- which ( grepl("[M+H]", p[,"adduct"], fixed=TRUE)
                       & dr[,"fold"] > 1
                       & dr[,"wt15"] > 1000 )

if (length(targetgroups) == 0) {
    message("Sorry, nothing of interest left :-(")
}

priorities <- order(dr[targetgroups, "fold"])

##
reporttab <- groups(faahko)[targetgroups[priorities],]

## Fix column names
## Need to fix code later ;-)

colnames(reporttab) <- sub("^rt$", "rtmed", colnames(reporttab))
colnames(reporttab) <- sub("^mz$", "mzmed", colnames(reporttab))

##
## The exclusion peakID list is for iterative
## method generation
##

templateFile <- system.file("20minKalibpos_Startermethod_MSMS.m",
                            package = "MetShot")

collisionEnergy <- c(20)

methodname <- paste(tempdir(), "/MSMS-faahKO-20eV", sep="")

picklist <- xcms2method(reporttab, methodPrefix=methodname,
                        widthFactor=1.5, minWidth=4,
                        template=templateFile,
                        MSMSManual_ListCollisionEnergy=collisionEnergy,
                        MSmode="positive")




###################################################
### code chunk number 3: picklist
###################################################
picklist


###################################################
### code chunk number 4: the leftovers
###################################################

collisionEnergies <- c(20)

pickLists <- list()

reporttabTargetRun <- rep(NA, nrow(reporttab))


## write bruker method
for (j in seq(length = length(collisionEnergies))) {
  methodname <- paste(tempdir(), "/MSMS-faahKO-20eV",
                      collisionEnergies[j], ".m", sep="")

  pickLists <- xcms2method(reporttab, method=methodname,
                           widthFactor=1.5, minWidth=4,
                           template=templateFile,
                           MSMSManual_ListCollisionEnergy=collisionEnergies[j],
                           MSmode="positive")

  message(paste("Created ", methodname,
                "with", length(pickLists), "Runs"))

  for (i in 1: length(pickLists)) {
    filename <- paste(methodname,"_",i, ".csv", sep="")
    write.csv(pickLists[[i]], file=filename)
  }
}

for (j in 1:length(pickLists)) {
  reporttabTargetRun[match(rownames(pickLists[[j]]), rownames(reporttab))] <- j
}

reporttab<-cbind(reporttab, reporttabTargetRun)



###################################################
### code chunk number 5: plotCoverage
###################################################
## plot overview

for (i in seq(1, length(pickLists))) {
  plotMS2windows(reporttab, pickLists[[i]],
                 peaks=ifelse(i==1, TRUE, FALSE),
                 col=i)
}



###################################################
### code chunk number 6: <Processing
###################################################

#######################################
##
## Parameters common to MS1 and MS2 picking
##

peakwidth=c(6,15)
ppm=25
snthresh=2
prefilter=c(2,20)


#######################################
##
## Read MS1 peaks
##

ms1peaks <- faahko

#######################################
##
## Read MS2 peaks
## Obtain MS2 peaks (ab)using normal peak picker
##

snthresh=2


## Create a pseudo-MS1 xraw
filename <- system.file("microtof/MM48_MSMSpos_MH1_15ev_1-A,2_01_9310.mzXML",
                        package = "MetShot")

xraw <- msn2xcms(xcmsRaw(filename, includeMSn=TRUE))

ms2peaks <- findPeaks(xraw, method="centWave",
                      snthresh=snthresh, prefilter=prefilter,
                      peakwidth=peakwidth, ppm=ppm, verbose.columns=T)


## for each peak
ms2precursor <- cbind(rt=xraw@msnRt, mz=xraw@msnPrecursorMz)


##
## CAMERA annotation of spectra
##

xs <- new("xcmsSet")
peaks(xs) <- ms2peaks
filepaths(xs) <- c(filename)
sampnames(xs) <- c("MM48_MSMSpos")
xs@peaks <- cbind(xs@peaks, sample=1)

xa <- xsAnnotate(xs)
xa <- groupFWHM(xa)
## xa <- groupCorrhack(xa,xraw,cor_eic_th=0.75)



###################################################
### code chunk number 7: plotRawMS2peaks
###################################################

plotGroups(xraw, ms2precursor, xa)



###################################################
### code chunk number 8: plotMS2peaks
###################################################

pspec <- 12

rt <- median(getpspectra(xa, pspec)[,"rt"])

mz <- ms2precursor[which(ms2precursor[,"rt"] == rt), "mz"]
sp <- getpspectra(xa, grp=pspec)[,c("mz", "maxo")]

plotPsSpectrum(xa, pspec=pspec,
          maxlabel=5, log=FALSE, sleep=0,
          title=paste("Spec:", pspec, "RT:", as.integer(rt), "m/z:", mz))



###################################################
### code chunk number 9: sessioninfo
###################################################
  toLatex(sessionInfo())


